@@ -38,6 +38,7 @@ def qry2df(qry, constr=None):
     try:
         df = []
         hdr = []
+        rows = None
 
         log(str(type(constr)))
         dsn = create_dns(constr)
@@ -46,11 +47,13 @@ def qry2df(qry, constr=None):
         )
         cur = con.cursor()
         cur.execute(qry)
-        rows = cur.fetchall()
+        try:
+            rows = cur.fetchall()
+        except:
+            con.commit()
         if rows:
             for cn in cur.description:
                 hdr.append(cn[0])
-        con.commit()
         con.close()
         if rows:
             df.append(hdr)
